@@ -1,4 +1,3 @@
-import gtk
 import math
 
 # CONSTS
@@ -151,45 +150,6 @@ protein_residues = {
 
 main_chain_atoms = {" N  ", " CA ", " C  ", " O  ", " CB "}
 
-atoms = {
-    "ALA": {" N  ", " CA ", " C  ", " O  ", " CB "},
-    "ARG": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD ", " NE ", " CZ ", " NH1", " NH2",},
-    "ASN": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " OD1", " ND2"},
-    "ASP": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " OD1", " OD2"},
-    "CYS": {" N  ", " CA ", " C  ", " O  ", " CB ", " SG "},
-    "GLN": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD ", " OE1", " NE2"},
-    "GLU": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD ", " OE1", " OE2"},
-    "GLY": {" N  ", " CA ", " C  ", " O  "},
-    "HIS": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " ND1", " CD2", " CE1", " NE2",},
-    "ILE": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG1", " CG2", " CD1"},
-    "LEU": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD1", " CD2"},
-    "LYS": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD ", " CE ", " NZ "},
-    "MET": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " SD ", " CE "},
-    "MSE": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", "SE  ", " CE "},
-    "PHE": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD1", " CD2", " CE1", " CE2", " CZ ",},
-    "PRO": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD "},
-    "SER": {" N  ", " CA ", " C  ", " O  ", " CB ", " OG "},
-    "THR": {" N  ", " CA ", " C  ", " O  ", " CB ", " OG1", " CG2"},
-    "TRP": {
-        " N  ",
-        " CA ",
-        " C  ",
-        " O  ",
-        " CB ",
-        " CG ",
-        " CD1",
-        " CD2",
-        " NE1",
-        " CE2",
-        " CE3",
-        " CZ2",
-        " CZ3",
-        " CH2",
-    },
-    "TYR": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG ", " CD1", " CD2", " CE1", " CE2", " CZ ", " OH ",},
-    "VAL": {" N  ", " CA ", " C  ", " O  ", " CB ", " CG1", " CG2"},
-}
-
 bonded = {
     " C  ": {" CA ", " O  ", " OXT"},
     " CA ": {" C  ", " CB ", " N  "},
@@ -313,23 +273,6 @@ def halfway(xyz1, xyz2):
     return [x, y, z]
 
 
-def is_protein(imol, name, res_spec):
-    if name in protein_residues:
-        return True
-    atom_names = []
-    atom_points = []
-    for info in residue_info_py(imol, *res_spec):
-        atom_names.append(info[0][0].strip())
-        atom_points.append(info[2])
-    if any(x not in atom_names for x in ("N", "CA", "C")):
-        return False
-    natoms = len(atom_names)
-    n = [atom_points[i] for i in range(natoms) if atom_names[i] == "N"][0]
-    ca = [atom_points[i] for i in range(natoms) if atom_names[i] == "CA"][0]
-    c = [atom_points[i] for i in range(natoms) if atom_names[i] == "C"][0]
-    return distance(n, ca) < 1.8 and distance(ca, c) < 1.8
-
-
 def attached_atoms(atom, residue):
     if atom.name == " N  " and residue.prev is not None:
         yield residue.prev.atoms[" C  "]
@@ -857,7 +800,7 @@ class Model:
                 ins_code = insertion_code_from_serial_number(imol, chain_id, serial_num)
                 spec = [chain_id, resno, ins_code]
                 name = residue_name(imol, *spec)
-                if is_protein(imol, name, spec):
+                if name in protein_residues:
                     residue = Residue(self, spec, name)
                     self.residues.append(residue)
                     self.residue_spec_dict[tuple(spec)] = residue
@@ -1040,327 +983,6 @@ class Model:
                 chain.correctness = mean(chain.correctnesses)
 
 
-# GUI
-
-
-class TodoListWindow(gtk.Window):
-    instance = None
-
-    def __init__(self, title, categories, height=600):
-        gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
-        self.check_input(categories)
-        self.set_title(title)
-        self.selected_todo = None
-        if TodoListWindow.instance is not None:
-            TodoListWindow.instance.destroy()
-        TodoListWindow.instance = self
-        self.init_content(categories)
-        self.show_all()
-        self.set_size(height)
-
-    def check_input(self, categories):
-        for category in categories:
-            assert "title" in category
-            assert "columns" in category
-            assert len(category["columns"]) > 0
-            assert "todos" in category
-            for todo in category["todos"]:
-                assert all(column in todo for column in category["columns"])
-                assert "point" in todo
-
-    def init_content(self, categories):
-        self.outside_vbox = gtk.VBox(spacing=2)
-        self.outside_vbox.set_border_width(2)
-        self.add(self.outside_vbox)
-        self.scrolled_window = gtk.ScrolledWindow()
-        self.scrolled_window.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
-        self.outside_vbox.pack_start(self.scrolled_window, True, True, 0)
-        self.inside_vbox = gtk.VBox()
-        self.scrolled_window.add_with_viewport(self.inside_vbox)
-        self.frames = []
-        for category in categories:
-            frame = TodoListFrame(self, category)
-            self.frames.append(frame)
-            self.inside_vbox.pack_start(frame, False, False, 5)
-        self.close_button = gtk.Button("Close")
-        self.close_button.connect("clicked", lambda b: self.destroy())
-        self.outside_vbox.pack_end(self.close_button, False, False, 0)
-
-    def set_size(self, height):
-        max_frame_height = height - 150
-        self.scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        size = self.get_size()
-        width = size[0] + 50
-        height = min(size[1] + 2, height)
-        self.resize(width, height)
-        for frame in self.frames:
-            if len(frame.todos) == 0:
-                continue
-            frame.scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-            height = 30 + 26 * len(frame.todos)
-            if height > max_frame_height:
-                height = max_frame_height
-            frame.scrolled_window.set_size_request(width - 50, height)
-        self.show_all()
-
-
-class TodoListFrame(gtk.Frame):
-    def __init__(self, window, category):
-        gtk.Frame.__init__(self)
-        self.parent_window = window
-        self.title = category["title"]
-        self.todos = category["todos"]
-        self.columns = category["columns"]
-        self.expanded = True
-        self.set_border_width(6)
-
-        title_event_box = gtk.EventBox()
-        self.title_label = gtk.Label()
-        self.set_title_label()
-        title_event_box.add(self.title_label)
-        title_event_box.connect("button-press-event", self.expand_contract)
-        self.set_label_widget(title_event_box)
-
-        self.contents = gtk.VBox()
-        if "description" in category:
-            description = gtk.Label(category["description"])
-            description.set_line_wrap(True)
-            self.contents.pack_start(description, False, False, 5)
-        if len(self.todos) > 0:
-            if "widget" in category:
-                self.contents.pack_start(category["widget"], False, False, 5)
-            self.init_list_store()
-            self.init_tree_view()
-            self.add_tree_view_with_scrolled_window()
-        self.add(self.contents)
-
-    def expand_contract(self, event_box, event):
-        self.expanded = not self.expanded
-        if self.expanded:
-            self.contents.show()
-        else:
-            self.contents.hide()
-        self.set_title_label()
-
-    def set_title_label(self):
-        button = "-" if self.expanded else "+"
-        done = 0 if not hasattr(self, "list_store") else [row[self.done_col] for row in self.list_store].count(True)
-        text = "%s %s (%d/%d)" % (button, self.title, done, len(self.todos))
-        self.title_label.set_label(text)
-
-    def init_list_store(self):
-        types = [type(self.todos[0][name]) for name in self.columns] + [
-            bool,
-            object,
-            object,
-        ]
-        self.done_col = len(self.columns)
-        self.xyz_col = len(self.columns) + 1
-        self.todo_col = len(self.columns) + 2
-        self.list_store = gtk.ListStore(*types)
-        for todo in self.todos:
-            todo["category"] = self.title
-            row = [todo[name] for name in self.columns] + [False, todo["point"], todo]
-            self.list_store.append(row)
-
-    def init_tree_view(self):
-        self.tree_view = gtk.TreeView(self.list_store)
-        for i, column_name in enumerate(self.columns):
-            renderer = gtk.CellRendererText()
-            column = gtk.TreeViewColumn(column_name, renderer)
-            column.add_attribute(renderer, "text", i)
-            column.add_attribute(renderer, "strikethrough", self.done_col)
-            column.set_expand(True)
-            column.set_sort_column_id(i)
-            self.tree_view.append_column(column)
-        renderer = gtk.CellRendererToggle()
-        renderer.connect("toggled", self.done_toggled)
-        column = gtk.TreeViewColumn("Done", renderer)
-        column.add_attribute(renderer, "active", self.done_col)
-        column.set_expand(True)
-        column.set_sort_column_id(self.done_col)
-        self.tree_view.append_column(column)
-        selection = self.tree_view.get_selection()
-        selection.set_mode(gtk.SELECTION_SINGLE)
-        self.tree_view.connect("cursor-changed", self.on_tree_view_selection)
-        self.tree_view.connect("button-release-event", self.button_released)
-        self.done_toggled_this_click = False
-
-    def add_tree_view_with_scrolled_window(self):
-        self.scrolled_window = gtk.ScrolledWindow()
-        self.scrolled_window.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
-        self.scrolled_window.add(self.tree_view)
-        self.contents.pack_start(self.scrolled_window, False, False, 5)
-
-    def done_toggled(self, widget, path):
-        self.list_store[path][self.done_col] = not self.list_store[path][self.done_col]
-        self.set_title_label()
-        self.done_toggled_this_click = True
-
-    def button_released(self, *args):
-        self.done_toggled_this_click = False
-
-    def on_tree_view_selection(self, tree_view):
-        if self.done_toggled_this_click:
-            return
-        selection = tree_view.get_selection()
-        model, treeiter = selection.get_selected()
-        if treeiter is not None:
-            xyz = model[treeiter][self.xyz_col]
-            todo = model[treeiter][self.todo_col]
-            set_rotation_centre(*xyz)
-            for frame in self.parent_window.frames:
-                if self == frame or len(frame.todos) == 0:
-                    continue
-                frame.tree_view.get_selection().unselect_all()
-            self.parent_window.selected_todo = todo
-
-
-def chain_todos(model):
-    todos = []
-    for chain_id in sorted(model.chains):
-        chain = model.chains[chain_id]
-        todos.append(
-            {
-                "Chain": chain_id,
-                "Length": len(chain.residues),
-                "UNKs": len([r for r in chain.residues if r.name == "UNK"]),
-                "Correctness": chain.correctness,
-                "point": model.chains[chain_id].residues[0].atoms[" CA "].point,
-            }
-        )
-    todos = sorted(todos, key=lambda todo: todo["Correctness"])
-    return todos
-
-
-def mainchain_todos(model):
-    todos = []
-    for residue in model.residues:
-        todos.append(
-            {
-                "Chain": residue.chain,
-                "Residue": residue.resno,
-                "Ins": residue.ins_code,
-                "Name": residue.name,
-                "Correctness": residue.main_chain_correctness,
-                "point": residue.atoms[" CA "].point,
-            }
-        )
-    todos = sorted(todos, key=lambda todo: todo["Correctness"])
-    return todos
-
-
-def sidechain_todos(model):
-    todos = []
-    for residue in model.residues:
-        if residue.truncatable:
-            todos.append(
-                {
-                    "Chain": residue.chain,
-                    "Residue": residue.resno,
-                    "Ins": residue.ins_code,
-                    "Name": residue.name,
-                    "Correctness": residue.side_chain_correctness,
-                    "point": residue.atoms[" CB "].point,
-                }
-            )
-    todos = sorted(todos, key=lambda todo: todo["Correctness"])
-    return todos
-
-
-def fill_option_menu_with_mol_options(menu, mol_nos):
-    for mol_no in mol_nos:
-        label = "%s %s" % (mol_no, molecule_name(mol_no))
-        menu.append_text(label)
-        menu.set_active(0)
-
-
-def imolmapdiff_chooser(callback):
-    imols = []
-    imaps = []
-    imap_diffs = []
-    for i in molecule_number_list():
-        if valid_model_molecule_qm(i):
-            imols.append(i)
-        elif valid_map_molecule_qm(i):
-            if map_is_difference_map(i):
-                imap_diffs.append(i)
-            else:
-                imaps.append(i)
-    if len(imols) == 0 or len(imaps) == 0 or len(imap_diffs) == 0:
-        print("ML_CORRECTNESS: Can't use ML Correctness: " "must have a valid model, map and difference map")
-        return
-
-    if len(imols) == 1 and len(imaps) == 1 and len(imap_diffs) == 1:
-        callback(imols[0], imaps[0], imap_diffs[0])
-        return
-
-    def destroy_window(*args):
-        window.destroy()
-        return False
-
-    def on_ok_clicked(*args):
-        imol = int(get_option_menu_active_molecule(imol_options, imols))
-        imap = int(get_option_menu_active_molecule(imap_options, imaps))
-        imap_diff = int(get_option_menu_active_molecule(imap_diff_options, imap_diffs))
-        callback(imol, imap, imap_diff)
-        destroy_window()
-
-    window = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    imol_options = gtk.combo_box_new_text()
-    fill_option_menu_with_mol_options(imol_options, imols)
-    imap_options = gtk.combo_box_new_text()
-    fill_option_menu_with_mol_options(imap_options, imaps)
-    imap_diff_options = gtk.combo_box_new_text()
-    fill_option_menu_with_mol_options(imap_diff_options, imap_diffs)
-    ok_button = gtk.Button("  OK  ")
-    ok_button.connect("clicked", on_ok_clicked)
-    cancel_button = gtk.Button(" Cancel ")
-    cancel_button.connect("clicked", destroy_window)
-
-    window.set_title("Coot")
-    vbox = gtk.VBox(False, 6)
-    window.add(vbox)
-    vbox.pack_start(gtk.Label("Model"), False, False, 5)
-    vbox.pack_start(imol_options, True, True, 0)
-    vbox.pack_start(gtk.Label("Map"), False, False, 5)
-    vbox.pack_start(imap_options, True, True, 0)
-    vbox.pack_start(gtk.Label("Difference Map"), False, False, 5)
-    vbox.pack_start(imap_diff_options, True, True, 0)
-    vbox.pack_start(gtk.HSeparator(), True, False, 2)
-    hbox_buttons = gtk.HBox(False, 5)
-    vbox.pack_start(hbox_buttons, False, False, 5)
-    hbox_buttons.pack_start(ok_button, True, False, 5)
-    hbox_buttons.pack_start(cancel_button, True, False, 5)
-    window.show_all()
-
-
-def show_gui(imol, imap, imap_diff):
-    model = Model(imol, imap, imap_diff)
-    TodoListWindow(
-        "ML Correctness",
-        [
-            {"title": "Chains", "columns": ["Chain", "Length", "UNKs", "Correctness"], "todos": chain_todos(model),},
-            {
-                "title": "Main chains",
-                "columns": ["Chain", "Residue", "Ins", "Name", "Correctness"],
-                "todos": mainchain_todos(model),
-            },
-            {
-                "title": "Side chains",
-                "columns": ["Chain", "Residue", "Ins", "Name", "Correctness"],
-                "todos": sidechain_todos(model),
-            },
-        ],
-    )
-
-
-if "coot_menubar_menu" in locals():
-    menu = coot_menubar_menu("ML Correctness")
-    add_simple_coot_menu_menuitem(menu, "GUI", lambda x: imolmapdiff_chooser(show_gui))
-    add_simple_coot_menu_menuitem(menu, "Prune", lambda x: imolmapdiff_chooser(prune))
-
-
 # SCRIPTING
 
 
@@ -1398,8 +1020,6 @@ def prune(
         max_deleted = len(model.residues) * max_chain_fraction
         deleted = 0
         remaining = []
-        chain_ids = model.chains.keys()
-        chain_ids.sort(key=lambda cid: model.chains[cid].correctness)
         for chain_id in sorted(model.chains,):
             chain = model.chains[chain_id]
             if (
